pub enum IfExists {
Error,
Append,
Overwrite,
Upsert(Vec<String>),
}Expand description
What to do if the destination already exists.
Variants
Error
If the destination exists, return an error.
Append
If the destination exists, try to append the new data.
Overwrite
If the destination exists, overwrite the existing data.
Upsert(Vec<String>)
If the destination exists, either update or insert using the specified
columns as the key. The list of keys must be non-empty, but we currently
only enforce that when parsing in FromStr.